@@ -50,12 +50,10 @@
 #'   \item{call}{Original function call}
 #'   \item{mf}{Marginality factor. Vector of length p that describes the location
 #'   of the species Hutchinsonian niche relative to the global niche}
-#'   \item{marginality}{Magnitude of the marginality factor, scaled by the
-#'   global covariance matrix}
+#'   \item{marginality}{Magnitude of the marginality factor}
 #'   \item{sf}{Sensitivity factor. Vector of length p that describes the amount of
 #'    sensitivity for each climate variable}
-#'   \item{sensitivity}{Magnitude of the sensitivity factor, scaled by the
-#'   global covariance matrix}
+#'   \item{sensitivity}{Square root of the mean of the sensitivity factor}
 #'   \item{eig}{Named vector of eigenvalues of specialization for each CNFA factor}
 #'   \item{co}{A p x p matrix describing the amount of marginality and specialization
 #'    in each CNFA factor.}
@@ -97,6 +95,10 @@
 #' and \code{marginality} and \code{sensitivity} are both returned as \code{NA}.
 #'
 #' @references
+#' Rinnan, D. Scott and Lawler, Joshua. Climate-niche factor analysis: a spatial
+#' approach to quantifying species vulnerability to climate change. Ecography (2019):
+#' \href{https://doi.org/10.1111/ecog.03937}{doi:10.1111/ecog.03937}.
+#'
 #' Basille, Mathieu, et al. Assessing habitat selection using multivariate
 #' statistics: Some refinements of the ecological-niche factor analysis. Ecological
 #' Modelling 211.1 (2008): 233-240.
@@ -137,6 +139,8 @@ setMethod("cnfa",
 
             if (nlayers(s.dat) > 1) stop('"s.dat" should be a single RasterLayer')
             if (!identicalCRS(raster(x), s.dat)) stop("climate and species projections do not match")
+            nS <- length(which(values(s.dat) > 0))
+            if(nS == 1) stop("CNFA is not meaningful for single observations")
             ras <- raster(x)
             ext <- extent(ras)
             ext.s <- extent(s.dat)
